pub struct LocateDataFile(pub String);Expand description
Ask the host to search for a file in its search paths.
Value should hold the simple filename.
The full path is returned as result of the function (String).
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for LocateDataFile
impl Debug for LocateDataFile