pub struct SetNumParams(pub usize);Expand description
Call this to override the number of parameters that this plugin instance has. This is meant for plugins that have a different set of parameters per instance.
The value holds the new number of parameters.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Debug for SetNumParams
impl Debug for SetNumParams