pub struct SetThreadSafe(pub bool);Expand description
(FL 7.0) Call this to let FL know that this plugin is thread-safe (or not). The default is not.
You should do your own thread-sync using
Host::lock_mix.
The value is false for not safe and true for safe.
Important: this should only be used from a generator plugin!
Tuple Fields
0: boolTrait Implementations
Sourceimpl Debug for SetThreadSafe
impl Debug for SetThreadSafe