InfoBuilder

Struct InfoBuilder 

pub struct InfoBuilder { /* private fields */ }
Use this to instantiate Info

Implementations

Source

impl InfoBuilder

pub fn new_effect(long_name: &str, short_name: &str, num_params: u32) -> Self

Initializer for an effect.

This is the most basic type.

pub fn new_full_gen(long_name: &str, short_name: &str, num_params: u32) -> Self

Initializer for a full standalone generator.

This is a combination of generator and note_input.

pub fn new_visual(long_name: &str, short_name: &str, num_params: u32) -> Self

Initializer for a purely visual plugin, that doesn’t process any audio data.

It’s a basic plugin with no_process enabled.

pub fn with_poly(self, poly: u32) -> Self

Set prefered (default) maximum polyphony.

pub fn with_out_ctrls(self, out_ctrls: u32) -> Self

Set number of internal output controllers.

pub fn with_out_voices(self, out_voices: u32) -> Self

Set number of internal output voices.

pub fn generator(self) -> Self

The plugin is a generator (as opposed to an effect).

pub fn get_chan_custom_shape(self) -> Self

The plugin will use a sample that the user loads into the plugin’s channel.

pub fn get_note_input(self) -> Self

The plugin reacts to note events.

pub fn want_new_tick(self) -> Self

The plugin will be notified on each tick and be able to control params (like a built-in MIDI controller).

pub fn no_process(self) -> Self

The plugin won’t process buffers at all (want_new_tick, or special visual plugins (Fruity NoteBook))

pub fn no_window(self) -> Self

The plugin’s editor window should be shown inside the channel properties window.

pub fn interfaceless(self) -> Self

(not used yet) The plugin doesn’t provide its own interface, but relies on the host to create one.

pub fn time_warp(self) -> Self

(not used yet) The plugin supports timewarps, that is can be told to change the playing position in a voice (direct from disk music tracks, …).

pub fn midi_out(self) -> Self

The plugin will send MIDI out messages. Only plugins specifying this option will be enabled when rendering to a midi file.

pub fn demo_version(self) -> Self

The plugin is a demo version. Practically this means the host won’t save its automation.

pub fn can_send(self) -> Self

The plugin has access to the send tracks, so it can’t be dropped into a send track or into the master.

pub fn loop_out(self) -> Self

The plugin will send delayed messages to itself (will require the internal sync clock to be enabled).

pub fn get_chan_sample(self) -> Self

This plugin as a generator will use the sample loaded in its parent channel (see host::Message::ChanSampleChanged).

pub fn want_fit_time(self) -> Self

Fit to time selector will appear in channel settings window (see host::Message::SetFitTime).

pub fn cant_smart_disable(self) -> Self

Plugin can’t be smart disabled.

pub fn want_settings_button(self) -> Self

Plugin wants a settings button on the titlebar (mainly for the wrapper).

pub fn build(self) -> Info

Finish builder and init Info