pub struct InfoBuilder { /* private fields */ }Expand description
Use this to instantiate Info
Implementations
Sourceimpl InfoBuilder
impl InfoBuilder
Sourcepub fn new_effect(long_name: &str, short_name: &str, num_params: u32) -> Self
pub fn new_effect(long_name: &str, short_name: &str, num_params: u32) -> Self
Initializer for an effect.
This is the most basic type.
Sourcepub fn new_full_gen(long_name: &str, short_name: &str, num_params: u32) -> Self
pub fn new_full_gen(long_name: &str, short_name: &str, num_params: u32) -> Self
Initializer for a full standalone generator.
This is a combination of generator and
note_input.
Sourcepub fn new_visual(long_name: &str, short_name: &str, num_params: u32) -> Self
pub fn new_visual(long_name: &str, short_name: &str, num_params: u32) -> Self
Initializer for a purely visual plugin, that doesn’t process any audio data.
It’s a basic plugin with no_process enabled.
Sourcepub fn with_out_ctrls(self, out_ctrls: u32) -> Self
pub fn with_out_ctrls(self, out_ctrls: u32) -> Self
Set number of internal output controllers.
Sourcepub fn with_out_voices(self, out_voices: u32) -> Self
pub fn with_out_voices(self, out_voices: u32) -> Self
Set number of internal output voices.
Sourcepub fn get_chan_custom_shape(self) -> Self
pub fn get_chan_custom_shape(self) -> Self
The plugin will use a sample that the user loads into the plugin’s channel.
Sourcepub fn get_note_input(self) -> Self
pub fn get_note_input(self) -> Self
The plugin reacts to note events.
Sourcepub fn want_new_tick(self) -> Self
pub fn want_new_tick(self) -> Self
The plugin will be notified on each tick and be able to control params (like a built-in MIDI controller).
Sourcepub fn no_process(self) -> Self
pub fn no_process(self) -> Self
The plugin won’t process buffers at all
(want_new_tick, or special visual plugins
(Fruity NoteBook))
Sourcepub fn no_window(self) -> Self
pub fn no_window(self) -> Self
The plugin’s editor window should be shown inside the channel properties window.
Sourcepub fn interfaceless(self) -> Self
pub fn interfaceless(self) -> Self
(not used yet) The plugin doesn’t provide its own interface, but relies on the host to create one.
Sourcepub fn time_warp(self) -> Self
pub fn time_warp(self) -> Self
(not used yet) The plugin supports timewarps, that is can be told to change the playing position in a voice (direct from disk music tracks, …).
Sourcepub fn midi_out(self) -> Self
pub fn midi_out(self) -> Self
The plugin will send MIDI out messages. Only plugins specifying this option will be enabled when rendering to a midi file.
Sourcepub fn demo_version(self) -> Self
pub fn demo_version(self) -> Self
The plugin is a demo version. Practically this means the host won’t save its automation.
Sourcepub fn can_send(self) -> Self
pub fn can_send(self) -> Self
The plugin has access to the send tracks, so it can’t be dropped into a send track or into the master.
Sourcepub fn loop_out(self) -> Self
pub fn loop_out(self) -> Self
The plugin will send delayed messages to itself (will require the internal sync clock to be enabled).
Sourcepub fn get_chan_sample(self) -> Self
pub fn get_chan_sample(self) -> Self
This plugin as a generator will use the sample loaded in its parent channel (see
host::Message::ChanSampleChanged).
Sourcepub fn want_fit_time(self) -> Self
pub fn want_fit_time(self) -> Self
Fit to time selector will appear in channel settings window (see
host::Message::SetFitTime).
Sourcepub fn cant_smart_disable(self) -> Self
pub fn cant_smart_disable(self) -> Self
Plugin can’t be smart disabled.
Plugin wants a settings button on the titlebar (mainly for the wrapper).